From 3c437014e887fafe5d78fff7c8573390403b4a90 Mon Sep 17 00:00:00 2001
From: Dylan Smith <Dylan.Smith@shopify.com>
Date: Sat, 22 Oct 2011 19:06:02 -0400
Subject: [PATCH 1/2] Clear errors before save.

Otherwise errors from previous save attempts will remain, so errors could
not be empty for a successful save attempt, and errors could include
irrelevant or duplicate errors messages for an unsuccessful save.
---
 src/activeresource.py            |    1 +
 src/tests/activeresource_test.py |   25 +++++++++++++++++++++++++
 2 files changed, 26 insertions(+)

diff --git a/src/activeresource.py b/src/activeresource.py
index 1f031c0..3ec2638 100755
--- a/src/activeresource.py
+++ b/src/activeresource.py
@@ -769,6 +769,7 @@ class ActiveResource(object):
             connection.Error: On any communications problems.
         """
         try:
+            self.errors.clear()
             if self.id:
                 response = self.klass.connection.put(
                         self._element_path(self.id, self._prefix_options),
diff --git a/src/tests/activeresource_test.py b/src/tests/activeresource_test.py
index a445a50..6486572 100644
--- a/src/tests/activeresource_test.py
+++ b/src/tests/activeresource_test.py
@@ -227,6 +227,31 @@ class ActiveResourceTest(unittest.TestCase):
         store.manager_id = 3
         store.save()
 
+    def test_save_with_errors(self):
+        self.http.respond_to(
+            'POST', '/stores.xml', self.xml_headers,
+            util.to_xml({'error': "Name can't be blank"}, root='errors'), 422)
+        store = self.store({'name': ''})
+        ret = store.save()
+        self.assertEqual(False, ret)
+        self.assertEqual({'name': ["can't be blank"]}, store.errors.errors)
+
+        self.http.respond_to(
+            'POST', '/stores.xml', self.xml_headers,
+            util.to_xml({'error': "Name is too short"}, root='errors'), 422)
+        store.name = 'x'
+        ret = store.save()
+        self.assertEqual(False, ret)
+        self.assertEqual({'name': ["is too short"]}, store.errors.errors)
+
+        self.http.respond_to(
+            'POST', '/stores.xml', self.xml_headers,
+            util.to_xml(self.general_store))
+        store.name = self.general_store['name']
+        ret = store.save()
+        self.assertEqual(True, ret)
+        self.assertEqual({}, store.errors.errors)
+
     def test_class_get(self):
         self.http.respond_to('GET', '/people/retrieve.xml?name=Matz',
                              {}, self.matz_array)
-- 
1.7.9.3

